@@ -1,4 +1,5 @@
 use std::collections::HashMap;
+use std::sync::atomic::{AtomicU32, Ordering};
 
 use proc_macro2::{Ident, Literal, Span, TokenStream};
 use quote::ToTokens;
@@ -8,6 +9,8 @@ use crate::{
   BindgenResult, FnKind, NapiImpl, NapiStruct, NapiStructKind, TryToTokens,
 };
 
+static NAPI_IMPL_ID: AtomicU32 = AtomicU32::new(0);
+
 // Generate trait implementations for given Struct.
 fn gen_napi_value_map_impl(name: &Ident, to_napi_val_impl: TokenStream) -> TokenStream {
   let name_str = name.to_string();
@@ -150,7 +153,10 @@ impl NapiStruct {
 
   fn gen_napi_value_map_impl(&self) -> TokenStream {
     match self.kind {
-      NapiStructKind::None => gen_napi_value_map_impl(&self.name, quote! {}),
+      NapiStructKind::None => gen_napi_value_map_impl(
+        &self.name,
+        self.gen_to_napi_value_ctor_impl_for_non_default_constructor_struct(),
+      ),
       NapiStructKind::Constructor => {
         gen_napi_value_map_impl(&self.name, self.gen_to_napi_value_ctor_impl())
       }
@@ -158,9 +164,45 @@ impl NapiStruct {
     }
   }
 
+  fn gen_to_napi_value_ctor_impl_for_non_default_constructor_struct(&self) -> TokenStream {
+    let name = &self.name;
+    let js_name_str = format!("{}\0", &self.js_name);
+    quote! {
+      impl napi::bindgen_prelude::ToNapiValue for #name {
+        unsafe fn to_napi_value(
+          env: napi::bindgen_prelude::sys::napi_env, val: #name
+        ) -> napi::bindgen_prelude::Result<napi::bindgen_prelude::sys::napi_value> {
+          if let Some(ctor_ref) = napi::bindgen_prelude::get_class_constructor(#js_name_str) {
+            let mut ctor = std::ptr::null_mut();
+
+            napi::bindgen_prelude::check_status!(
+              napi::bindgen_prelude::sys::napi_get_reference_value(env, ctor_ref, &mut ctor),
+              "Failed to get constructor of class `{}`",
+              #js_name_str
+            )?;
+
+            let mut result = std::ptr::null_mut();
+            napi::bindgen_prelude::___CALL_FROM_FACTORY.store(true, std::sync::atomic::Ordering::Relaxed);
+            napi::bindgen_prelude::check_status!(
+              napi::bindgen_prelude::sys::napi_new_instance(env, ctor, 0, std::ptr::null_mut(), &mut result),
+              "Failed to construct class `{}`",
+              #js_name_str
+            )?;
+            napi::bindgen_prelude::___CALL_FROM_FACTORY.store(false, std::sync::atomic::Ordering::Relaxed);
+            Ok(result)
+          } else {
+            Err(napi::bindgen_prelude::Error::new(
+              napi::bindgen_prelude::Status::InvalidArg, format!("Failed to get constructor of class `{}`", #js_name_str))
+            )
+          }
+        }
+      }
+    }
+  }
+
   fn gen_to_napi_value_ctor_impl(&self) -> TokenStream {
     let name = &self.name;
-    let js_name_str = &self.js_name;
+    let js_name_str = format!("{}\0", &self.js_name);
 
     let mut field_conversions = vec![];
     let mut field_destructions = vec![];
@@ -476,7 +518,11 @@ impl NapiImpl {
     let name_str = self.name.to_string();
     let js_name = format!("{}\0", self.js_name);
     let mod_name = Ident::new(
-      &format!("__napi_impl_helper__{}", name_str),
+      &format!(
+        "__napi_impl_helper__{}__{}",
+        name_str,
+        NAPI_IMPL_ID.fetch_add(1, Ordering::SeqCst)
+      ),
       Span::call_site(),
     );
 
