@@ -3,9 +3,14 @@ use super::{ToTypeDef, TypeDef};
 use crate::{js_doc_from_comments, ty_to_ts_type, typegen::add_alias, NapiConst};
 
 impl ToTypeDef for NapiConst {
-  fn to_type_def(&self) -> TypeDef {
+  fn to_type_def(&self) -> Option<TypeDef> {
+    if self.skip_typescript {
+      return None;
+    }
+
     add_alias(self.name.to_string(), self.js_name.to_string());
-    TypeDef {
+
+    Some(TypeDef {
       kind: "const".to_owned(),
       name: self.js_name.to_owned(),
       def: format!(
@@ -15,6 +20,6 @@ impl ToTypeDef for NapiConst {
       ),
       js_mod: self.js_mod.to_owned(),
       js_doc: js_doc_from_comments(&self.comments),
-    }
+    })
   }
 }
