@@ -10,13 +10,14 @@ thread_local! {
 }
 
 impl ToTypeDef for NapiStruct {
-  fn to_type_def(&self) -> TypeDef {
+  fn to_type_def(&self) -> Option<TypeDef> {
     CLASS_STRUCTS.with(|c| {
       c.borrow_mut()
         .insert(self.name.to_string(), self.js_name.clone());
     });
     add_alias(self.name.to_string(), self.js_name.to_string());
-    TypeDef {
+
+    Some(TypeDef {
       kind: String::from(if self.kind == NapiStructKind::Object {
         "interface"
       } else {
@@ -26,36 +27,42 @@ impl ToTypeDef for NapiStruct {
       def: self.gen_ts_class(),
       js_mod: self.js_mod.to_owned(),
       js_doc: js_doc_from_comments(&self.comments),
-    }
+    })
   }
 }
 
 impl ToTypeDef for NapiImpl {
-  fn to_type_def(&self) -> TypeDef {
+  fn to_type_def(&self) -> Option<TypeDef> {
     if let Some(output_type) = &self.task_output_type {
       TASK_STRUCTS.with(|t| {
         t.borrow_mut()
           .insert(self.js_name.clone(), ty_to_ts_type(output_type, false).0);
       });
     }
-    TypeDef {
+
+    Some(TypeDef {
       kind: "impl".to_owned(),
       name: self.js_name.to_owned(),
       def: self
         .items
         .iter()
-        .map(|f| {
-          format!(
-            "{}{}",
-            js_doc_from_comments(&f.comments),
-            f.to_type_def().def
-          )
+        .filter_map(|f| {
+          if f.skip_typescript {
+            None
+          } else {
+            Some(format!(
+              "{}{}",
+              js_doc_from_comments(&f.comments),
+              f.to_type_def()
+                .map_or(String::default(), |type_def| type_def.def)
+            ))
+          }
         })
         .collect::<Vec<_>>()
         .join("\\n"),
       js_mod: self.js_mod.to_owned(),
       js_doc: "".to_string(),
-    }
+    })
   }
 }
 
@@ -66,7 +73,11 @@ impl NapiStruct {
       .fields
       .iter()
       .filter(|f| f.getter)
-      .map(|f| {
+      .filter_map(|f| {
+        if f.skip_typescript {
+          return None;
+        }
+
         let mut field_str = String::from("");
 
         if !f.comments.is_empty() {
@@ -84,7 +95,7 @@ impl NapiStruct {
         }
         field_str.push_str(&arg);
 
-        field_str
+        Some(field_str)
       })
       .collect::<Vec<_>>()
       .join("\\n");
